<h1 align="center">Gruvboxify 🎨</h1>

<p align="center">
<img src="https://img.shields.io/badge/license-mit-sometext?style=for-the-badge&labelColor=504945&color=83a598" style="width: auto; height: 30px">
<img src="https://img.shields.io/pypi/v/gruvboxify?style=for-the-badge&labelColor=504945&color=d65d0e" style="width: auto; height: 30px">
</p>

> "If autumn had a terminal, it would be Gruvbox."

<img src="https://iili.io/3G2hUw7.png" alt="An example of Gruvboxify in action" />

Gruvboxify is a simple CLI tool that turns any image into Gruvbox colors.

<h6>More examples <a href="https://freeimage.host/a/gruvboxify-demo.vapQ1">here.</a></h6>

## Installation

Gruvboxify can be installed by typing `pip install gruvboxify` in your terminal

## Usage

To use Gruvboxify, type `gruvboxify absolute/path/to/image.png` in your terminal.
This will create a Gruvboxified image in the same folder as the image.

To direct the output image to a specific folder, type `gruvboxify absolute/path/to/image.jpg -o absolute/path/to/folder/` in your terminal.
This will create a Gruvboxified image in the specified folder.

For assistance, type `gruvboxify -h` in your terminal.

<hr>

###### <samp>Inspiration: [gruvbox-factory 🏭](https://github.com/paulopacitti/gruvbox-factory/tree/master)</samp>
